@@ -47,28 +47,22 @@ describe 'swift::storage::container' do
       end
     end
 
-    context 'with disabled service managing and service provider' do
+    context 'with disabled service management' do
       before do
         params.merge!({
-          :manage_service   => false,
-          :enabled          => false,
-          :service_provider => 'swiftinit',
+          :manage_service => false,
         })
       end
 
-      it 'configures services' do
-        { 'swift-container-server'     => 'swift-container-server',
-          'swift-container-replicator' => 'swift-container-replicator',
-          'swift-container-updater'    => 'swift-container-updater',
-          'swift-container-auditor'    => 'swift-container-auditor',
-          'swift-container-sync'       => 'swift-container-sync' }.each do |service_alias, service_name|
-          is_expected.to contain_service(service_alias).with(
-            :ensure    => nil,
-            :name      => service_name,
-            :enable    => false,
-            :tag       => 'swift-service',
-            :provider  => 'swiftinit',
-          )
+      it 'does not configure services' do
+        [
+          'swift-container-server',
+          'swift-container-replicator',
+          'swift-container-updater',
+          'swift-container-auditor',
+          'swift-container-sync'
+        ].each do |service_alias|
+          is_expected.to_not contain_service(service_alias)
         end
       end
     end
@@ -83,7 +77,7 @@ describe 'swift::storage::container' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :service_names => {
               'swift-container-server'     => 'swift-container',
