@@ -74,6 +74,8 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_account_config('DEFAULT/bind_ip').with_value('10.0.0.1')
         is_expected.to contain_swift_account_config('DEFAULT/bind_port').with_value('6002')
         is_expected.to contain_swift_account_config('DEFAULT/mount_check').with_value(true)
+        is_expected.to contain_swift_account_config('DEFAULT/disable_fallocate').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_account_config('DEFAULT/fallocate_reserve').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('DEFAULT/user').with_value('swift')
         is_expected.to contain_swift_account_config('DEFAULT/workers').with_value(4)
         is_expected.to contain_swift_account_config('DEFAULT/log_name').with_value('account-server')
@@ -87,6 +89,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_account_config('app:account-server/set log_level').with_value('INFO')
         is_expected.to contain_swift_account_config('app:account-server/set log_requests').with_value(true)
         is_expected.to contain_swift_account_config('app:account-server/set log_address').with_value('/dev/log')
+        is_expected.to contain_swift_account_config('app:account-server/fallocate_reserve').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_port').with_value('<SERVICE DEFAULT>')
@@ -191,6 +194,8 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_container_config('DEFAULT/bind_ip').with_value('10.0.0.1')
         is_expected.to contain_swift_container_config('DEFAULT/bind_port').with_value('6001')
         is_expected.to contain_swift_container_config('DEFAULT/mount_check').with_value(true)
+        is_expected.to contain_swift_container_config('DEFAULT/disable_fallocate').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_config('DEFAULT/fallocate_reserve').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('DEFAULT/user').with_value('swift')
         is_expected.to contain_swift_container_config('DEFAULT/workers').with_value(4)
         is_expected.to contain_swift_container_config('DEFAULT/log_name').with_value('container-server')
@@ -204,6 +209,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_container_config('app:container-server/set log_level').with_value('INFO')
         is_expected.to contain_swift_container_config('app:container-server/set log_requests').with_value(true)
         is_expected.to contain_swift_container_config('app:container-server/set log_address').with_value('/dev/log')
+        is_expected.to contain_swift_container_config('app:container-server/fallocate_reserve').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_swift_container_config('DEFAULT/log_statsd_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('DEFAULT/log_statsd_port').with_value('<SERVICE DEFAULT>')
@@ -312,6 +318,8 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_object_config('DEFAULT/bind_ip').with_value('10.0.0.1')
         is_expected.to contain_swift_object_config('DEFAULT/bind_port').with_value('6000')
         is_expected.to contain_swift_object_config('DEFAULT/mount_check').with_value(true)
+        is_expected.to contain_swift_object_config('DEFAULT/disable_fallocate').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_object_config('DEFAULT/fallocate_reserve').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('DEFAULT/user').with_value('swift')
         is_expected.to contain_swift_object_config('DEFAULT/workers').with_value(4)
         is_expected.to contain_swift_object_config('DEFAULT/log_name').with_value('object-server')
@@ -325,6 +333,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_object_config('app:object-server/set log_level').with_value('INFO')
         is_expected.to contain_swift_object_config('app:object-server/set log_requests').with_value(true)
         is_expected.to contain_swift_object_config('app:object-server/set log_address').with_value('/dev/log')
+        is_expected.to contain_swift_object_config('app:object-server/fallocate_reserve').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_swift_object_config('DEFAULT/log_statsd_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('DEFAULT/log_statsd_port').with_value('<SERVICE DEFAULT>')
